@@ -94,7 +94,7 @@ def compass_to_vis_set(compass, z=0, custom_angles=None, projection=None, font='
                 arc_geo = Arc3D.from_arc2d(circle, z)
                 result.append(DisplayArc3D(arc_geo, line_width=1, line_type='Dotted'))
             for txt, pt in zip(compass.ALTITUDES, compass.orthographic_altitude_points):
-                txt_pln = Plane(o=Point3D(pt.x, pt.y, z), x=xaxis)
+                txt_pln = Plane(o=Point3D(pt.x, pt.y, z + 0.01), x=xaxis)
                 d_txt = DisplayText3D(
                     str(txt), txt_pln, min_txt, None, font, 'Center', 'Top')
                 result.append(d_txt)
@@ -103,7 +103,7 @@ def compass_to_vis_set(compass, z=0, custom_angles=None, projection=None, font='
                 arc_geo = Arc3D.from_arc2d(circle, z)
                 result.append(DisplayArc3D(arc_geo, line_width=1, line_type='Dotted'))
             for txt, pt in zip(compass.ALTITUDES, compass.stereographic_altitude_points):
-                txt_pln = Plane(o=Point3D(pt.x, pt.y, z), x=xaxis)
+                txt_pln = Plane(o=Point3D(pt.x, pt.y, z + 0.01), x=xaxis)
                 d_txt = DisplayText3D(
                     str(txt), txt_pln, min_txt, None, font, 'Center', 'Top')
                 result.append(d_txt)
